@@ -16,7 +16,18 @@ logger = Logger(__file__)
 
 def contact_info(request, slug):
     if request.method == 'GET':
-        form = facade.ContactForm()
+        user = request.user
+        if user.is_authenticated:
+            try:
+                payment_profile = facade.get_user_payment_profile(user.id)
+            except facade.UserPaymentProfileDoesNotExist:
+                form = facade.ContactForm({'name': user.first_name, 'email': user.email})
+            else:
+                form = facade.ContactForm(
+                    {'name': payment_profile.name, 'email': payment_profile.email, 'phone': payment_profile.phone}
+                )
+        else:
+            form = facade.ContactForm()
         ctx = {'contact_form': form, 'slug': slug}
         return render(request, 'django_pagarme/contact_form.html', ctx)
 
@@ -35,7 +46,7 @@ def contact_info(request, slug):
         return redirect(f'{path}?{query_string}')
 
 
-def capture(request, token):
+def capture(request, slug, token):
     try:
         payment = facade.capture(token, request.user.id)
     except facade.PaymentViolation as e:
@@ -46,7 +57,7 @@ def capture(request, token):
             ctx = {'payment': payment}
             return render(request, 'django_pagarme/show_boleto_data.html', ctx)
         else:
-            return redirect(reverse('django_pagarme:thanks', kwargs={'slug': payment.first_item_slug()}))
+            return redirect(reverse('django_pagarme:thanks', kwargs={'slug': slug}))
 
 
 def thanks(request, slug):
@@ -64,7 +75,7 @@ def notification(request, slug):
     transaction_id = request.POST['transaction[id]']
     current_status = request.POST['current_status']
     try:
-        facade.handle_notification(transaction_id, current_status, raw_body, expected_signature)
+        facade.handle_notification(transaction_id, current_status, raw_body, expected_signature, request.POST)
     except PaymentViolation:
         return HttpResponseBadRequest()
     except InvalidNotificationStatusTransition:
